@@ -49,9 +49,7 @@ describe 'tripleo::profile::base::cinder::api' do
         is_expected.to contain_class('tripleo::profile::base::cinder')
         is_expected.to contain_class('tripleo::profile::base::cinder::authtoken')
         is_expected.to contain_class('cinder::api').with(
-          :sync_db        => true,
-          # Verify legacy key manager is enabled when none is set in hiera.
-          :keymgr_backend => 'cinder.keymgr.conf_key_mgr.ConfKeyManager',
+          :sync_db => true,
         )
         is_expected.to contain_class('tripleo::profile::base::apache')
       end
@@ -83,11 +81,9 @@ describe 'tripleo::profile::base::cinder::api' do
         is_expected.to contain_class('tripleo::profile::base::cinder')
         is_expected.to contain_class('tripleo::profile::base::cinder::authtoken')
         is_expected.to contain_class('cinder::api').with(
-          :sync_db        => true,
-          :keymgr_backend => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
+          :sync_db => true,
         )
         is_expected.to contain_class('tripleo::profile::base::apache')
-        is_expected.to contain_cinder__type('tripleo')
       end
     end
 
@@ -97,16 +93,14 @@ describe 'tripleo::profile::base::cinder::api' do
         :bootstrap_node => 'other.example.com',
       } }
 
-      it 'should trigger complete configuration but with no db sync or default volume type' do
+      it 'should trigger complete configuration but with no db sync' do
         is_expected.to contain_class('tripleo::profile::base::cinder::api')
         is_expected.to contain_class('tripleo::profile::base::cinder')
         is_expected.to contain_class('tripleo::profile::base::cinder::authtoken')
         is_expected.to contain_class('cinder::api').with(
-          :sync_db        => false,
-          :keymgr_backend => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
+          :sync_db => false,
         )
         is_expected.to contain_class('tripleo::profile::base::apache')
-        is_expected.to_not contain_cinder__type('tripleo')
       end
     end
   end
