@@ -288,25 +288,6 @@ describe 'tripleo::profile::base::cinder::volume' do
             )
           end
         end
-       end
-
-      context 'with only veritas hyperscale' do
-        before :each do
-          params.merge!({
-            :cinder_enable_vrts_hs_backend => true,
-            :cinder_enable_iscsi_backend   => false,
-          })
-        end
-        it 'should configure only veritas hyperscale' do
-          is_expected.to contain_class('tripleo::profile::base::cinder::volume::veritas_hyperscale')
-          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::iscsi')
-          is_expected.to contain_class('tripleo::profile::base::cinder::volume')
-          is_expected.to contain_class('tripleo::profile::base::cinder')
-          is_expected.to contain_class('cinder::volume')
-          is_expected.to contain_class('cinder::backends').with(
-            :enabled_backends => ['Veritas_HyperScale']
-          )
-        end
       end
 
       context 'with only nfs' do
@@ -333,7 +314,6 @@ describe 'tripleo::profile::base::cinder::volume' do
           params.merge!({
             :cinder_enable_rbd_backend   => true,
             :cinder_enable_iscsi_backend => false,
-            :cinder_rbd_client_name      => 'openstack'
           })
         end
         it 'should configure only ceph' do
@@ -345,18 +325,15 @@ describe 'tripleo::profile::base::cinder::volume' do
           is_expected.to contain_class('cinder::backends').with(
             :enabled_backends => ['tripleo_ceph']
           )
-          is_expected.to contain_exec('exec-setfacl-openstack-cinder')
-          is_expected.to contain_exec('exec-setfacl-openstack-cinder-mask')
         end
-        context 'additional rbd pools' do
-          # The list of additional rbd pools is not an input, but instead comes
-          # from hiera. Step 4's hiera data doesn't define additional RBD pools,
-          # so test the feature by defining extra pools in step 5 (see
-          # ../fixtures/hieradata/step5.yaml).
+        context 'additional rbd pools and an additional rbd backend' do
+          # Step 5's hiera specifies two rbd backends, each with additional rbd pools
           let(:params) { { :step => 5 } }
           it 'should configure additional rbd backends' do
             is_expected.to contain_class('cinder::backends').with(
-              :enabled_backends => ['tripleo_ceph', 'tripleo_ceph_foo', 'tripleo_ceph_bar']
+              :enabled_backends => [
+                'tripleo_ceph_1', 'tripleo_ceph_2', 'tripleo_ceph_1_foo', 'tripleo_ceph_1_bar', 'tripleo_ceph_2_zap',
+              ]
             )
           end
         end
@@ -380,7 +357,6 @@ describe 'tripleo::profile::base::cinder::volume' do
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellemc_powerstore')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellemc_vxflexos')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::netapp')
-          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::veritas_hyperscale')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::nfs')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::rbd')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume')
@@ -407,7 +383,6 @@ describe 'tripleo::profile::base::cinder::volume' do
             :cinder_enable_dellemc_xtremio_backend    => true,
             :cinder_enable_dellemc_vxflexos_backend   => true,
             :cinder_enable_netapp_backend             => true,
-            :cinder_enable_vrts_hs_backend            => true,
           })
         end
         it 'should configure all backends' do
@@ -421,7 +396,6 @@ describe 'tripleo::profile::base::cinder::volume' do
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_powerstore')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_vxflexos')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::netapp')
-          is_expected.to contain_class('tripleo::profile::base::cinder::volume::veritas_hyperscale')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::nfs')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::rbd')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume')
@@ -430,7 +404,7 @@ describe 'tripleo::profile::base::cinder::volume' do
           is_expected.to contain_class('cinder::backends').with(
             :enabled_backends => ['tripleo_iscsi', 'tripleo_ceph', 'tripleo_pure', 'tripleo_dellsc', 'tripleo_dellemc_sc','tripleo_dellemc_powerflex',
                                   'tripleo_dellemc_powermax', 'tripleo_dellemc_powerstore','tripleo_dellemc_vxflexos', 'tripleo_dellemc_xtremio',
-                                  'tripleo_netapp','tripleo_nfs','Veritas_HyperScale']
+                                  'tripleo_netapp','tripleo_nfs']
           )
         end
       end
